@@ -1,10 +1,19 @@
 from django.utils import simplejson
 
 class Flash(dict):
- 
+
     def __setitem__(self, key, msg):
         self.setdefault(key, []).append(msg)
- 
+
+    def __getattr__(self, key):
+        try:
+            return self[key]
+        except KeyError, e:
+            raise AttributeError(e.message)
+
+    def __setattr__(self, key, msg):
+        self.__setitem__(key, msg)
+
 
 class FlashMiddleware(object):
 
@@ -20,7 +29,7 @@ class FlashMiddleware(object):
         Create empty request.flash attribute for later items assigments in views
         """
         request.flash = Flash()
- 
+
     def process_response(self, request, response):
         """
         if request.flash have data, put it to cookies,
